==> deew-2.5.3.tar.gz: deew-2.5.3/deew/messages.py <==
error_messages = {
    'changelog'        : 'couldn\'t fetch changelog from GitHub.',
    'delay'            : 'unsupported delay value.',
    'wsl_path'         : 'WSL path conversion doesn\'t work with [bold yellow]🤠[/bold yellow].',
    'create_dir'       : 'failed to create [bold yellow]🤠[/bold yellow].',
    'format'           : '[bold yellow]-f[/bold yellow]/[bold yellow]--format[/bold yellow] can only be [bold yellow]dd[/bold yellow], [bold yellow]ddp[/bold yellow] or [bold yellow]thd[/bold yellow].',
    'downmix'          : '[bold yellow]-dm[/bold yellow]/[bold yellow]--downmix[/bold yellow] can only be [bold yellow]1[/bold yellow], [bold yellow]2[/bold yellow] or [bold yellow]6[/bold yellow].',
    'downmix_mismatch' : 'downmix value has to be lower than the number of input channels.',
    'thd_downmix'      : '[bold yellow]-m[/bold yellow]/[bold yellow]--mix[/bold yellow] can only be used for [bold yellow]DD[/bold yellow]/[bold yellow]DDP[/bold yellow] encoding.',
    'drc'              : 'allowed DRC values: [bold yellow]film_light[/bold yellow], [bold yellow]film_standard[/bold yellow], [bold yellow]music_light[/bold yellow], [bold yellow]music_standard[/bold yellow], [bold yellow]speech[/bold yellow].',
    'linux_thd'        : 'Linux version of DEE does not support TrueHD encoding.',
    'path'             : 'path [bold yellow]🤠[/bold yellow] does not exist.',
    'ffprobe'          : 'input file couldn\'t be parsed by ffprobe, try to extract/remux it with ffmpeg or mkvmerge.',
    'sample_mismatch'  : 'each input has to have the same sample rate:\n🤠',
    'channel_mismatch' : 'each input has to have the same channel count:\n🤠',
    'bitdepth_mismatch': 'each input has to have the same bit depth:\n🤠',
    'channels'         : 'number of input channels can only be [bold yellow]1[/bold yellow], [bold yellow]2[/bold yellow], [bold yellow]6[/bold yellow] or [bold yellow]8[/bold yellow].',
    'binary_exist'     : '[bold yellow]🤠[/bold yellow] does not exist.',
    'config_key'       : 'the following keys are missing from your config file: 🤠.'
}

==> deew-2.8.3.tar.gz: deew-2.8.3/deew/messages.py <==
error_messages = {
    'changelog'        : 'couldn\'t fetch changelog from GitHub.',
    'delay'            : 'unsupported delay value.',
    'wsl_path'         : 'WSL path conversion doesn\'t work with [bold yellow]🤠[/bold yellow].',
    'create_dir'       : 'failed to create [bold yellow]🤠[/bold yellow].',
    'format'           : '[bold yellow]-f[/bold yellow]/[bold yellow]--format[/bold yellow] can only be [bold yellow]dd[/bold yellow], [bold yellow]ddp[/bold yellow] or [bold yellow]thd[/bold yellow].',
    'downmix'          : '[bold yellow]-dm[/bold yellow]/[bold yellow]--downmix[/bold yellow] can only be [bold yellow]1[/bold yellow], [bold yellow]2[/bold yellow] or [bold yellow]6[/bold yellow].',
    'downmix_mismatch' : 'downmix value has to be lower than the number of input channels.',
    'thd_downmix'      : '[bold yellow]-m[/bold yellow]/[bold yellow]--mix[/bold yellow] can only be used for [bold yellow]DD[/bold yellow]/[bold yellow]DDP[/bold yellow] encoding.',
    'drc'              : 'allowed DRC values: [bold yellow]film_light[/bold yellow], [bold yellow]film_standard[/bold yellow], [bold yellow]music_light[/bold yellow], [bold yellow]music_standard[/bold yellow], [bold yellow]speech[/bold yellow].',
    'linux_thd'        : 'Linux version of DEE does not support TrueHD encoding.',
    'path'             : 'path [bold yellow]🤠[/bold yellow] does not exist.',
    'ffprobe'          : 'input file couldn\'t be parsed by ffprobe, try to extract/remux it with ffmpeg or mkvmerge.',
    'sample_mismatch'  : 'each input has to have the same sample rate:\n🤠',
    'channel_mismatch' : 'each input has to have the same channel count:\n🤠',
    'bitdepth_mismatch': 'each input has to have the same bit depth:\n🤠',
    'channels'         : 'number of input channels can only be [bold yellow]1[/bold yellow], [bold yellow]2[/bold yellow], [bold yellow]6[/bold yellow] or [bold yellow]8[/bold yellow].',
    'binary_exist'     : '[bold yellow]🤠[/bold yellow] does not exist.',
    'config_key'       : 'the following keys are missing from your config file: 🤠.\n Update your config file.'
}
